@@ -9,6 +9,7 @@ use anyhow::{anyhow, Result};
 use regex::Regex;
 
 use crate::book::epub::EpubLoader;
+use crate::book::haodoo::HaodooLoader;
 use crate::book::html::HtmlLoader;
 use crate::book::txt::TxtLoader;
 use crate::common::char_index_for_byte;
@@ -20,6 +21,7 @@ use crate::view::TraceInfo;
 mod epub;
 mod txt;
 mod html;
+mod haodoo;
 
 pub const EMPTY_CHAPTER_CONTENT: &str = "No content.";
 
@@ -35,6 +37,9 @@ pub struct Link {
 
 impl Line {
 	pub fn push(&mut self, ch: char) {
+		if ch == '\0' {
+			return;
+		}
 		self.chars.push(ch);
 	}
 
@@ -177,11 +182,11 @@ pub trait Book {
 	fn next_chapter(&mut self) -> Result<Option<usize>> {
 		self.goto_chapter(self.current_chapter() + 1)
 	}
-	fn goto_chapter(&mut self, chapter: usize) -> Result<Option<usize>> {
-		if chapter >= self.chapter_count() {
+	fn goto_chapter(&mut self, chapter_index: usize) -> Result<Option<usize>> {
+		if chapter_index >= self.chapter_count() {
 			return Ok(None);
 		} else {
-			Ok(Some(chapter))
+			Ok(Some(chapter_index))
 		}
 	}
 	fn current_chapter(&self) -> usize { 0 }
@@ -199,14 +204,22 @@ pub struct BookLoader {
 }
 
 pub(crate) trait Loader {
-	fn support(&self, filename: &str) -> bool;
-	fn load_file(&self, filename: &str, chapter: usize) -> Result<Box<dyn Book>> {
-		let mut file = OpenOptions::new().read(true).open(filename)?;
+	fn extensions(&self) -> &Vec<&'static str>;
+	fn support(&self, filename: &str) -> bool {
+		let filename = filename.to_lowercase();
+		for extension in self.extensions() {
+			if filename.ends_with(extension) {
+				return true;
+			}
+		}
+		false
+	}
+	fn load_file(&self, filename: &str, mut file: std::fs::File, chapter_index: usize) -> Result<Box<dyn Book>> {
 		let mut content: Vec<u8> = Vec::new();
 		file.read_to_end(&mut content)?;
-		self.load_buf(filename, content, chapter)
+		self.load_buf(filename, content, chapter_index)
 	}
-	fn load_buf(&self, filename: &str, buf: Vec<u8>, chapter: usize) -> Result<Box<dyn Book>>;
+	fn load_buf(&self, filename: &str, buf: Vec<u8>, chapter_index: usize) -> Result<Box<dyn Book>>;
 }
 
 impl BookLoader {
@@ -222,7 +235,10 @@ impl BookLoader {
 		for loader in self.loaders.iter() {
 			if loader.support(filename) {
 				let book = match content {
-					File(..) => loader.load_file(filename, chapter)?,
+					File(..) => {
+						let file = OpenOptions::new().read(true).open(filename)?;
+						loader.load_file(filename, file, chapter)?
+					}
 					Buf(buf) => loader.load_buf(filename, buf, chapter)?,
 				};
 				return Ok(book);
@@ -235,9 +251,10 @@ impl BookLoader {
 impl Default for BookLoader {
 	fn default() -> Self {
 		let mut loaders: Vec<Box<dyn Loader>> = Vec::new();
-		loaders.push(Box::new(TxtLoader {}));
-		loaders.push(Box::new(EpubLoader {}));
-		loaders.push(Box::new(HtmlLoader {}));
+		loaders.push(Box::new(TxtLoader::new()));
+		loaders.push(Box::new(EpubLoader::new()));
+		loaders.push(Box::new(HtmlLoader::new()));
+		loaders.push(Box::new(HaodooLoader::new()));
 		BookLoader { loaders }
 	}
 }
