@@ -16,23 +16,20 @@ impl Book for TxtBook {
 	}
 }
 
-pub struct TxtLoader {}
+pub struct TxtLoader {
+	extensions: Vec<&'static str>,
+}
 
 impl TxtLoader {
-	pub(crate) fn support(filename: &str) -> bool {
-		let filename = filename.to_lowercase();
-		filename.ends_with(".txt")
-			|| filename.ends_with(".log")
-			|| filename.ends_with(".json")
-			|| filename.ends_with(".yaml")
-			|| filename.ends_with(".yml")
-			|| filename.ends_with(".js")
+	pub(crate) fn new() -> Self {
+		let extensions = vec![".txt", ".log", ".json", ".yaml", ".yml", ".js"];
+		TxtLoader { extensions }
 	}
 }
 
 impl Loader for TxtLoader {
-	fn support(&self, filename: &str) -> bool {
-		Self::support(filename)
+	fn extensions(&self) -> &Vec<&'static str> {
+		&self.extensions
 	}
 
 	fn load_buf(&self, filename: &str, content: Vec<u8>, _chapter: usize) -> anyhow::Result<Box<dyn Book>> {
