@@ -1,5 +1,3 @@
-use std::cmp::Ordering;
-
 use cursive::Cursive;
 use cursive::event::Key::Esc;
 use cursive::traits::Scrollable;
@@ -16,26 +14,6 @@ impl<'a> ListEntry<'a> {
 	}
 }
 
-impl<'a> Eq for ListEntry<'a> {}
-
-impl<'a> PartialEq<Self> for ListEntry<'a> {
-	fn eq(&self, other: &Self) -> bool {
-		self.title.eq(other.title)
-	}
-}
-
-impl<'a> PartialOrd<Self> for ListEntry<'a> {
-	fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
-		self.title.partial_cmp(other.title)
-	}
-}
-
-impl<'a> Ord for ListEntry<'a> {
-	fn cmp(&self, other: &Self) -> Ordering {
-		self.title.cmp(other.title)
-	}
-}
-
 pub(crate) fn list_dialog<'a, F, I>(title: &str, iterator: I, current_value: usize, callback: F) -> OnEventView<Dialog>
 	where
 		F: Fn(&mut Cursive, usize) + 'static,
